@@ -56,8 +56,10 @@ def version():
         - BaseListView再次简化, 省略get_base_serializer步骤, 只需要list_fields和retrieve_fields即可       # 2.5.0
         - `.django.utils.get_field_names_by_model`增加`exclude_ls`功能, 并按原模型字段顺序排序
         - 完善高级检索功能, AddQS现在支持无限Q_ls的嵌套了     # 2.5.1
+        - 过滤条件fn以`__isnull`结尾时, value自动转换为bool类型        # 2.6.0
+        - autoWiki兼容list_fields和retrieve_fields
     """
-    v = "2.5.1"  # 当前: 2.5.1
+    v = "2.6.0"  # 当前: 2.6.0
     return v
 
 
