@@ -90,9 +90,9 @@ class AutoWiki(APIView):
         vs = []
         for f in func_ls:
             md = getattr(views, f)
-            if hasattr(md, 'queryset') and hasattr(md, 'serializer_class'):
+            if hasattr(md, 'queryset') and (hasattr(md, 'serializer_class') or hasattr(md, 'list_fields') or hasattr(md, 'retrieve_fields')):
                 print('---------', f, md)
-                if getattr(md, 'queryset') is not None and (getattr(md, 'serializer_class') or getattr(md, 'list_serializer_class') or getattr(md, 'auto_generate_serializer_class') or getattr(md, 'retrieve_serializer_class')):
+                if getattr(md, 'queryset') is not None and (getattr(md, 'serializer_class') or getattr(md, 'list_serializer_class') or getattr(md, 'auto_generate_serializer_class') or getattr(md, 'retrieve_serializer_class')) or getattr(md, 'list_fields') or getattr(md, 'retrieve_fields'):
                     if not view_class_name or f in view_class_name:
                         s += 1
                         print(f, md)
@@ -210,6 +210,17 @@ class AutoWiki(APIView):
                 # v__serializer_class.__dict__.get('_declared_fields')
                 v.serializer_class = v__serializer_class
 
+            if not v.serializer_class:
+                list_serializer_class = retrieve_serializer_class = None
+                if hasattr(v, 'list_fields'):
+                    list_fields = getattr(v, 'list_fields')
+                    list_serializer_class = get_base_serializer(v.queryset, list_fields)
+
+                if hasattr(v, 'retrieve_fields'):
+                    retrieve_fields = getattr(v, 'retrieve_fields')
+                    retrieve_serializer_class = get_base_serializer(v.queryset, retrieve_fields)
+                v.serializer_class = list_serializer_class or retrieve_serializer_class
+
             # --- 把serializers里面的拓展字段通过__doc__转义后加进field_names
             serializer_field_ls = v.serializer_class.__dict__.get('_declared_fields')
             text = v.serializer_class.__doc__ or ""
